Module skills

Module skills 

Enums

SkillLoadingError
Errors that can occur while loading a skill from disk.

Constants

SKILLS_PATH
Relative path to the project-local skills directory.

Statics

GLOBAL_SKILLS_PATH
Lazily-initialised path to the global skills directory (~/.agents/skills).

Functions

ensure_skill
Locate a skill by name, preferring the local project directory.
find_skills
Discover all available skills in both local and global directories.
global_skills_path
Return the global skills directory, creating the cached path on first call.
parse_skill
Parse a skill’s SKILL.md and return its description.