Skip to main contentModule skills
Source - SkillLoadingError
- Errors that can occur while loading a skill from disk.
- SKILLS_PATH
- Relative path to the project-local skills directory.
- GLOBAL_SKILLS_PATH
- Lazily-initialised path to the global skills directory (
~/.agents/skills).
- ensure_skill
- Locate a skill by name, preferring the local project directory.
- find_skills
- Discover all available skills in both local and global directories.
- global_skills_path
- Return the global skills directory, creating the cached path on first call.
- parse_skill
- Parse a skill’s
SKILL.md and return its description.